/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * ------------------------------------------------------------------------- $Id
 * : $ -------------------------------------------------------------------------
 */

package org.ow2.petals.se.quartz;

import java.util.logging.Level;

import javax.jbi.JBIException;

import org.ow2.petals.component.framework.bc.AbstractBindingComponent;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.impl.StdSchedulerFactory;

/**
 * 
 * @version $Rev: $ $Date: $
 * @author alouis
 */
public class QuartzEngine extends AbstractBindingComponent {

    private Scheduler quartzScheduler = null;

    public Scheduler getQuartzScheduler() {
        return quartzScheduler;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.AbstractComponent#doInit()
     */
    @Override
    public void doInit() throws JBIException {
        try {
            getLogger().info("initialize the Quartz scheduler");
            this.quartzScheduler = StdSchedulerFactory.getDefaultScheduler();

        } catch (final SchedulerException e) {
            final String msg = "Error when creating scheduler";
            this.getLogger().log(Level.SEVERE, msg);
            throw new JBIException(msg, e);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.AbstractComponent#doStart()
     */
    @Override
    public void doStart() throws JBIException {
        try {
            getLogger().info("start the Quartz scheduler");
            this.quartzScheduler.start();
        } catch (final SchedulerException e) {
            final String msg = "Error when starting scheduler";
            this.getLogger().log(Level.SEVERE, msg);
            throw new JBIException(msg, e);
        }
    }

    public void doStop() throws JBIException {
        try {
            getLogger().info("stop the Quartz scheduler, wait for jobs to complete");
            this.quartzScheduler.shutdown(true);
        } catch (final SchedulerException e) {
            final String msg = "Error when stopping scheduler";
            this.getLogger().log(Level.SEVERE, msg);
            throw new JBIException(msg, e);
        }
    }

    public void doShutdown() throws JBIException {
        try {
            getLogger().info("shutdown the Quartz scheduler");
            this.quartzScheduler.shutdown(false);
        } catch (final SchedulerException e) {
            final String msg = "Error when shutdown scheduler";
            this.getLogger().log(Level.SEVERE, msg);
            throw new JBIException(msg, e);
        }
    }

}
