/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * ------------------------------------------------------------------------- $Id
 * : $ -------------------------------------------------------------------------
 */
package org.ow2.petals.se.quartz;

import java.text.ParseException;
import java.util.logging.Level;

import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.listener.AbstractExternalListener;
import org.ow2.petals.se.quartz.job.EmitSignalJob;
import org.quartz.CronTrigger;
import org.quartz.JobDataMap;
import org.quartz.JobDetail;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
/**
 * 
 * @author alouis
 *
 */
public class SchedulerManager extends AbstractExternalListener {

    @Override
    protected void start() throws PEtALSCDKException {
        getLogger().info("define a new scheduled job");
        QuartzEngine quartzEngine = (QuartzEngine) getComponent();
        Scheduler scheduler = quartzEngine.getQuartzScheduler();

        String cronExpression =getExtensions().get(Constants.CRON_EXPRESSION);
        getLogger().finest("cron expression is "+cronExpression);

        try {
            JobDetail jobDetail = new JobDetail(QuartzUtils.generateJobName(getConsumes()),Scheduler.DEFAULT_GROUP,
                    EmitSignalJob.class);
            JobDataMap jobDataMap = new JobDataMap();
            jobDataMap.put(Constants.SCHEDULER_MANAGER, this);
            jobDetail.setJobDataMap(jobDataMap);
            getLogger().finest("a new job is created");
            
            CronTrigger trigger = new CronTrigger(QuartzUtils.generateTriggerName(getConsumes()),Scheduler.DEFAULT_GROUP,cronExpression);
            getLogger().finest("a cron-trigger is created");

            scheduler.scheduleJob(jobDetail,trigger);
            getLogger().info("a new scheduled emit signal job ("+cronExpression+") is added to call "+QuartzUtils.generateJobName(getConsumes()));

        } catch (SchedulerException e) {
            getLogger().log(Level.SEVERE,e.getMessage(),e);
        } catch (ParseException e) {
            getLogger().log(Level.SEVERE,e.getMessage(),e);
        }
    }

    @Override
    protected void stop() throws PEtALSCDKException {
        QuartzEngine quartzEngine = (QuartzEngine) getComponent();
        Scheduler scheduler = quartzEngine.getQuartzScheduler();
        try {
            scheduler.deleteJob(QuartzUtils.generateJobName(getConsumes()), Scheduler.DEFAULT_GROUP);
            String cronExpression =getExtensions().get(Constants.CRON_EXPRESSION);
            getLogger().info("delete the scheduled emit signal job ("+cronExpression+") for "+QuartzUtils.generateJobName(getConsumes()));
        } catch (SchedulerException e) {
            getLogger().log(Level.SEVERE,e.getMessage(),e);
        }

    }

   

}
